@@ -45,6 +45,23 @@ define([
                 x: '',
                 y: '',
                 hue: '',
+                bins: '',
+                kde: '',
+                stat: '',
+                showValues: false,
+                // axes options
+                x_limit_from: '',
+                x_limit_to: '',
+                y_limit_from: '',
+                y_limit_to: '',
+                xticks: '',
+                xticks_label: '',
+                xticks_rotate: '',
+                removeXticks: false,
+                yticks: '',
+                yticks_label: '',
+                yticks_rotate: '',
+                removeYticks: false,
                 // info options
                 title: '',
                 x_label: '',
@@ -56,11 +73,8 @@ define([
                 useGrid: '',
                 gridColor: '#000000',
                 markerStyle: '',
-                // setting options
-                x_limit_from: '',
-                x_limit_to: '',
-                y_limit_from: '',
-                y_limit_to: '',
+                // code option
+                userCode: '',
                 // preview options
                 useSampling: true,
                 sampleCount: 30,
@@ -117,6 +131,16 @@ define([
                 { label: 'diamond', value: 'D', title: 'diamond' }, 
                 { label: 'thin diamond', value: 'd', title: 'thin_diamond' }
             ]
+
+            this.statList = [
+                { label: 'Select option...', value: '' },
+                { label: 'count', value: "'count'" },
+                { label: 'frequency', value: "'frequency'" },
+                { label: 'density', value: "'density'" },
+                { label: 'probability', value: "'probability'" },
+                { label: 'proportion', value: "'proportion'" },
+                { label: 'percent', value: "'percent'" }
+            ];
         }
 
         _bindEvent() {
@@ -157,6 +181,22 @@ define([
                 $(that.wrapSelector(com_util.formatString('.vp-tab-page-box.{0} > .vp-tab-page', level))).hide();
                 $(that.wrapSelector(com_util.formatString('.vp-tab-page[data-type="{0}"]', type))).show();
             });
+
+            // change chart type
+            $(this.wrapSelector('#chartType')).on('change', function() {
+                // add bins to histplot
+                let chartType = $(this).val();
+                $(that.wrapSelector('.sb-option')).hide();
+                if (chartType == 'histplot') {
+                    $(that.wrapSelector('#bins')).closest('.sb-option').show();
+                    $(that.wrapSelector('#kde')).closest('.sb-option').show();
+                    $(that.wrapSelector('#stat')).closest('.sb-option').show();
+                } else if (chartType == 'barplot') {
+                    $(that.wrapSelector('#showValues')).closest('.sb-option').show();
+                } else if (chartType == 'countplot') {
+                    $(that.wrapSelector('#showValues')).closest('.sb-option').show();
+                }
+            });
             
             // use data or not
             $(this.wrapSelector('#setXY')).on('change', function() {
@@ -196,6 +236,36 @@ define([
                 $(that.wrapSelector('#color')).prop('disabled', $(this).prop('checked') == false);
             });
 
+            // axes - ticks location
+            $(this.wrapSelector('#xticks')).on('change', function() {
+                let val = $(this).val();
+                if (val !== '') {
+                    // enable xticks_label
+                    $(that.wrapSelector('#xticks_label')).prop('readonly', false);
+                } else {
+                    // disable xticks_label
+                    $(that.wrapSelector('#xticks_label')).prop('readonly', true);
+                }
+            });
+            $(this.wrapSelector('#yticks')).on('change', function() {
+                let val = $(this).val();
+                if (val !== '') {
+                    // enable yticks_label
+                    $(that.wrapSelector('#yticks_label')).prop('readonly', false);
+                } else {
+                    // disable yticks_label
+                    $(that.wrapSelector('#yticks_label')).prop('readonly', true);
+                }
+            });
+
+            // axes - ticks label: inform user to type location option to use label
+            $(this.wrapSelector('#xticks_label[readonly]')).on('click', function() {
+                $(that.wrapSelector('#xticks')).focus();
+            });
+            $(this.wrapSelector('#yticks_label[readonly]')).on('click', function() {
+                $(that.wrapSelector('#yticks')).focus();
+            });
+
             // preview refresh
             $(this.wrapSelector('#previewRefresh')).on('click', function() {
                 that.loadPreview();
@@ -240,6 +310,7 @@ define([
                 pageThis: this,
                 id: 'data',
                 select: function(value, dtype) {
+                    that.state.data = value;
                     that.state.dtype = dtype;
 
                     if (dtype == 'DataFrame') {
@@ -298,6 +369,26 @@ define([
             });
             $(page).find('#markerStyle').html(markerTag.toString());
 
+            // x, yticks label check
+            if (this.state.xticks && this.state.xticks !== '') {
+                $(page).find('#xticks_label').prop('readonly', false);
+            }
+            if (this.state.yticks && this.state.yticks !== '') {
+                $(page).find('#yticks_label').prop('readonly', false);
+            }
+
+            // stat options
+            let statTag = new com_String();
+            this.statList.forEach(stat => {
+                let selectedFlag = '';
+                if (stat.value == that.state.stat) {
+                    selectedFlag = 'selected';
+                }
+                statTag.appendFormatLine('<option value="{0}" {1}>{2}</option>',
+                    stat.value, selectedFlag, stat.label);
+            });
+            $(page).find('#stat').html(statTag.toString());
+
             // preview sample count
             let sampleCountList = [30, 50, 100, 300, 500, 700, 1000];
             let sampleCountTag = new com_String();
@@ -311,6 +402,18 @@ define([
             });
             $(page).find('#sampleCount').html(sampleCountTag.toString());
 
+            // data options depend on chart type
+            $(page).find('.sb-option').hide();
+            if (this.state.chartType == 'histplot') {
+                $(page).find('#bins').closest('.sb-option').show();
+                $(page).find('#kde').closest('.sb-option').show();
+                $(page).find('#stat').closest('.sb-option').show();
+            } else if (this.state.chartType == 'barplot') {
+                $(page).find('#showValues').closest('.sb-option').show();
+            } else if (this.state.chartType == 'countplot') {
+                $(page).find('#showValues').closest('.sb-option').show();
+            }
+
             //================================================================
             // Load state
             //================================================================
@@ -414,6 +517,25 @@ define([
                     $(this.wrapSelector('#hue')).prop('disabled', true);
                 }
             }
+
+            // load code tab - code mirror
+            let that = this;
+            let userCodeKey = 'userCode1';
+            let userCodeTarget = this.wrapSelector('#' + userCodeKey);
+            this.codeArea = this.initCodemirror({
+                key: userCodeKey,
+                selector: userCodeTarget,
+                events: [{
+                    key: 'change',
+                    callback: function(instance, evt) {
+                        // save its state
+                        instance.save();
+                        that.state[userCodeKey] = $(userCodeTarget).val();
+                        // refresh preview
+                        that.loadPreview();
+                    }
+                }]
+            });
             
             this.loadPreview();
         }
@@ -583,10 +705,13 @@ define([
 
         generateCode(preview=false) {
             let { 
-                chartType, data, x, y, hue, setXY, userOption='', 
+                chartType, data, x, y, setXY, hue, kde, stat, showValues, userOption='', 
+                x_limit_from, x_limit_to, y_limit_from, y_limit_to,
+                xticks, xticks_label, xticks_rotate, removeXticks,
+                yticks, yticks_label, yticks_rotate, removeYticks,
                 title, x_label, y_label, legendPos,
                 useColor, color, useGrid, gridColor, markerStyle,
-                x_limit_from, x_limit_to, y_limit_from, y_limit_to,
+                userCode1,
                 useSampling, sampleCount 
             } = this.state;
 
@@ -605,19 +730,15 @@ define([
                 // TODO: marker to seaborn argument (ex. marker='+' / markers={'Lunch':'s', 'Dinner':'X'})
                 etcOptionCode.push(com_util.formatString("marker='{0}'", markerStyle));
             }
+            if (showValues === true && chartType === 'barplot') {
+                etcOptionCode.push('ci=None');
+            }
 
             // add user option
             if (userOption != '') {
                 etcOptionCode.push(userOption);
             }
 
-            if (etcOptionCode.length > 0) {
-                etcOptionCode = [
-                    '',
-                    ...etcOptionCode
-                ]
-            }
-
             if (preview && useSampling) {
                 // data sampling code for preview
                 // convertedData = data + '.sample(n=' + sampleCount + ', random_state=0)';
@@ -641,8 +762,59 @@ define([
                 }
             }   
 
-            let generatedCode = com_generator.vp_codeGenerator(this, config, state, etcOptionCode.join(', '));
+            let generatedCode = com_generator.vp_codeGenerator(this, config, state
+                , etcOptionCode.length > 0? ', ' + etcOptionCode.join(', '): '');
 
+            // Axes
+            if (x_limit_from != '' && x_limit_to != '') {
+                chartCode.appendFormatLine("plt.xlim(({0}, {1}))", x_limit_from, x_limit_to);
+            }
+            if (y_limit_from != '' && y_limit_to != '') {
+                chartCode.appendFormatLine("plt.ylim(({0}, {1}))", y_limit_from, y_limit_to);
+            }
+            if (legendPos != '') {
+                chartCode.appendFormatLine("plt.legend(loc='{0}')", legendPos);
+            }
+            if (removeXticks === true) {
+                // use empty list to disable xticks
+                chartCode.appendLine("plt.xticks([])");
+            } else {
+                let xticksOptList = [];
+                if (xticks && xticks !== '') {
+                    xticksOptList.push('ticks=' + xticks);
+                    // Not able to use xticks_label without xticks
+                    if (xticks_label && xticks_label != '') {
+                        xticksOptList.push('labels=' + xticks_label);
+                    }
+                }
+                if (xticks_rotate && xticks_rotate !== '') {
+                    xticksOptList.push('rotation=' + xticks_rotate)
+                }
+                // Add option to chart code if available
+                if (xticksOptList.length > 0) {
+                    chartCode.appendFormatLine("plt.xticks({0})", xticksOptList.join(', '));
+                }
+            }
+            if (removeYticks === true) {
+                // use empty list to disable yticks
+                chartCode.appendLine("plt.yticks([])");
+            } else {
+                let yticksOptList = [];
+                if (yticks && yticks !== '') {
+                    yticksOptList.push('ticks=' + yticks);
+                    // Not able to use xticks_label without xticks
+                    if (yticks_label && yticks_label != '') {
+                        yticksOptList.push('labels=' + yticks_label);
+                    }
+                }
+                if (yticks_rotate && yticks_rotate !== '') {
+                    yticksOptList.push('rotation=' + yticks_rotate)
+                }
+                // Add option to chart code if available
+                if (yticksOptList.length > 0) {
+                    chartCode.appendFormatLine("plt.yticks({0})", yticksOptList.join(', '));
+                }
+            }
             // Info
             if (title && title != '') {
                 chartCode.appendFormatLine("plt.title('{0}')", title);
@@ -653,15 +825,6 @@ define([
             if (y_label && y_label != '') {
                 chartCode.appendFormatLine("plt.ylabel('{0}')", y_label);
             }
-            if (x_limit_from != '' && x_limit_to != '') {
-                chartCode.appendFormatLine("plt.xlim(({0}, {1}))", x_limit_from, x_limit_to);
-            }
-            if (y_limit_from != '' && y_limit_to != '') {
-                chartCode.appendFormatLine("plt.ylim(({0}, {1}))", y_limit_from, y_limit_to);
-            }
-            if (legendPos != '') {
-                chartCode.appendFormatLine("plt.legend(loc='{0}')", legendPos);
-            }
             // Style - Grid
             // plt.grid(True, axis='x', color='red', alpha=0.5, linestyle='--')
             let gridCodeList = [];
@@ -674,9 +837,7 @@ define([
             if (gridCodeList.length > 0) {
                 chartCode.appendFormatLine("plt.grid({0})", gridCodeList.join(', '));
             }
-            chartCode.append('plt.show()');
 
-            let convertedData = data;
             if (preview) {
                 // Ignore warning
                 code.appendLine('import warnings');
@@ -688,13 +849,31 @@ define([
                 let defaultHeight = 6;
                 code.appendFormatLine('plt.figure(figsize=({0}, {1}))', defaultWidth, defaultHeight);
 
-                code.appendLine(generatedCode);
+                if (showValues && showValues === true) {
+                    code.appendLine('ax = ' + generatedCode);
+                    code.appendLine("vp_seaborn_show_values(ax)");
+                } else {
+                    code.appendLine(generatedCode);  
+                }
                 code.appendLine(chartCode.toString());
             } else {
-                code.appendLine(generatedCode);
-                code.appendLine(chartCode.toString());
+                if (showValues && showValues === true) {
+                    code.appendLine('ax = ' + generatedCode);
+                    code.appendLine("vp_seaborn_show_values(ax)");
+                } else {
+                    code.appendLine(generatedCode);  
+                }
+                if (chartCode.length > 0) {
+                    code.append(chartCode.toString());
+                }
             }
 
+            if (userCode1 && userCode1 != '') {
+                code.appendLine(userCode1);
+            }
+
+            code.append('plt.show()');
+
             // remove last Enter(\n) from code and then run it
             return code.toString().replace(/\n+$/, "");
         }
